ConvKBInteraction
=================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: ConvKBInteraction
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ConvKBInteraction.func
      ~ConvKBInteraction.reset_parameters

   .. rubric:: Methods Documentation

   .. automethod:: func
   .. automethod:: reset_parameters
